@@ -33,10 +33,10 @@ def main(
     temporary_lines
         Mapping from temporary lines to original lines.
     """
-    with open(notebook, "r") as handle:
+    with open(notebook) as handle:
         notebook_json = json.load(handle)
 
-    with open(str(python_file), "r") as handle:
+    with open(str(python_file)) as handle:
         pyfile = handle.read()
 
     pycells = pyfile[len(CODE_SEPARATOR) :].split(CODE_SEPARATOR)
@@ -66,7 +66,7 @@ def main(
         List[str]
             New source that can be saved into Jupyter Notebook.
         """
-        rstripped_source = source.rstrip("\n")
+        rstripped_source = source.rstrip()
         if cell_number in trailing_semicolons and not rstripped_source.endswith(";"):
             source = rstripped_source + ";"
         # we take [1:] because the first cell is just '\n'
